module AnchorUi
  module Sprockets
    module Assets
      class CoreUiIcons < Base
        include AnchorUi::Core::Assets::Concerns::Zip

        def self.asset_name
          'coreui-icons'
        end

        # No version tags on github repo...
        def version
          'master'
        end

        def update
          download url, zip_path
          unzip
          compile_core_scss
          move
          clear
        end

        private

        def zip_name
          "#{version}.zip"
        end

        def url
          "https://github.com/coreui/coreui-icons/archive/#{zip_name}"
        end

        def fonts_destination_path
          fonts_path.join asset_name
        end

        def stylesheets_destination_path
          stylesheets_path.join asset_name
        end

        def fonts_source_path
          extraction_path.join 'fonts'
        end

        def stylesheets_source_path
          extraction_path.join 'scss'
        end

        def compile_core_scss
          filename = '_core.scss'
          scss = read_scss(filename, newline: false)
          scss.gsub! 'url', 'font-url'
          File.write stylesheets_source_path.join(filename), scss
        end

        def move
          FileUtils.rm_rf fonts_destination_path
          FileUtils.mv(
            fonts_source_path,
            fonts_destination_path
          )
          FileUtils.rm_rf stylesheets_destination_path
          FileUtils.mv(
            stylesheets_source_path,
            stylesheets_destination_path
          )
        end

      end
    end
  end
end
